Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(112)

Unified Diff: webkit/browser/fileapi/file_system_context.h

Issue 18344013: fileapi: Rename FileSystemMountProvider to FileSystemBackend (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/file_system_context.h
diff --git a/webkit/browser/fileapi/file_system_context.h b/webkit/browser/fileapi/file_system_context.h
index 21d48be36630dc3c52de8de9e29cbd957bd6cf43..c7ddf1d4810371046167d2378cd12ddf39dea545 100644
--- a/webkit/browser/fileapi/file_system_context.h
+++ b/webkit/browser/fileapi/file_system_context.h
@@ -48,11 +48,11 @@ namespace fileapi {
class AsyncFileUtil;
class CopyOrMoveFileValidatorFactory;
-class ExternalFileSystemMountPointProvider;
+class ExternalFileSystemBackend;
class ExternalMountPoints;
class FileStreamWriter;
class FileSystemFileUtil;
-class FileSystemMountPointProvider;
+class FileSystemBackend;
class FileSystemOperation;
class FileSystemOperationRunner;
class FileSystemOptions;
@@ -102,7 +102,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
ExternalMountPoints* external_mount_points,
quota::SpecialStoragePolicy* special_storage_policy,
quota::QuotaManagerProxy* quota_manager_proxy,
- ScopedVector<FileSystemMountPointProvider> additional_providers,
+ ScopedVector<FileSystemBackend> additional_providers,
const base::FilePath& partition_path,
const FileSystemOptions& options);
@@ -134,7 +134,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns the mount point provider instance for the given |type|.
// This may return NULL if it is given an invalid or unsupported filesystem
// type.
- FileSystemMountPointProvider* GetMountPointProvider(
+ FileSystemBackend* GetMountPointProvider(
FileSystemType type) const;
// Returns true for sandboxed filesystems. Currently this does
@@ -150,10 +150,10 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns all registered filesystem types.
void GetFileSystemTypes(std::vector<FileSystemType>* types) const;
// Returns a FileSystemMountPointProvider instance for external filesystem
// type, which is used only by chromeos for now. This is equivalent to
// calling GetMountPointProvider(kFileSystemTypeExternal).
- ExternalFileSystemMountPointProvider* external_provider() const;
+ ExternalFileSystemBackend* external_provider() const;
// Used for OpenFileSystem.
typedef base::Callback<void(base::PlatformFileError result,
@@ -236,7 +236,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
#endif
private:
- typedef std::map<FileSystemType, FileSystemMountPointProvider*>
+ typedef std::map<FileSystemType, FileSystemBackend*>
MountPointProviderMap;
// For CreateFileSystemOperation.
@@ -276,9 +276,9 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// For initial provider_map construction. This must be called only from
// the constructor.
- void RegisterMountPointProvider(FileSystemMountPointProvider* provider);
+ void RegisterMountPointProvider(FileSystemBackend* provider);
- // Returns a FileSystemMountPointProvider, used only by test code.
+ // Returns a FileSystemBackend, used only by test code.
SandboxMountPointProvider* sandbox_provider() const {
return sandbox_provider_.get();
}
@@ -292,7 +292,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
scoped_ptr<IsolatedMountPointProvider> isolated_provider_;
// Additional mount point providers.
- ScopedVector<FileSystemMountPointProvider> additional_providers_;
+ ScopedVector<FileSystemBackend> additional_providers_;
// Registered mount point providers.
// The map must be constructed in the constructor since it can be accessed
@@ -150,10 +150,10 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns all registered filesystem types.
void GetFileSystemTypes(std::vector<FileSystemType>* types) const;
- // Returns a FileSystemMountPointProvider instance for external filesystem
+ // Returns a FileSystemBackend instance for external filesystem
// type, which is used only by chromeos for now. This is equivalent to
// calling GetMountPointProvider(kFileSystemTypeExternal).

Powered by Google App Engine
This is Rietveld 408576698